@@ -523,7 +523,7 @@ typedef SanitizerPatchResult (SANITIZERAPI *SanitizerCallbackClusterBarrierArriv
  * \retval SANITIZER_PATCH_SUCCESS Warp execution continues.
  * \retval SANITIZER_PATCH_ERROR Warp should be exited.
  */
-typedef SanitizerPatchResult (SANITIZERAPI *SanitizerCallbackClusterBarrierArrive)(void* userdata, uint64_t pc);
+typedef SanitizerPatchResult (SANITIZERAPI *SanitizerCallbackClusterBarrierWait)(void* userdata, uint64_t pc);
 
 /**
  * \brief Flags describing a warpgroup aligned MMA async.
@@ -992,6 +992,12 @@ typedef enum {
      */
     SANITIZER_INSTRUCTION_CUDA_BARRIER_ATTEMPT        = 39,
 
+    /**
+     * Entering cluster barrier wait instruction. The type of the callback must
+     * be SanitizerCallbackClusterBarrierWait.
+     */
+    SANITIZER_INSTRUCTION_CLUSTER_BARRIER_WAIT_ENTRY  = 40,
+
     SANITIZER_INSTRUCTION_FORCE_INT                   = 0x7fffffff
 } Sanitizer_InstructionId;
 
